---
title: <span class="badge builder"></span> MuteTiming
---
# <span class="badge builder"></span> MuteTiming

## Constructor

```python
MuteTiming()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> alerting.MuteTiming
```

### <span class="badge object-method"></span> name

```python
def name(name: str) -> typing.Self
```

### <span class="badge object-method"></span> time_intervals

```python
def time_intervals(time_intervals: list[cogbuilder.Builder[alerting.TimeInterval]]) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [MuteTiming](./object-MuteTiming.md)
